==> haskell-shell-escape-0.2.0-155-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-shell-escape.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 shell-escape
version:              0.2.0
visibility:           public
id:                   shell-escape-0.2.0-31vqIL3ffgTBybBmBztQi6
key:                  shell-escape-0.2.0-31vqIL3ffgTBybBmBztQi6
license:              BSD-3-Clause
maintainer:           oss@solidsnack.be
author:               Jason Dusek
homepage:             http://github.com/solidsnack/shell-escape
synopsis:             Shell escaping library.
description:
    Shell escaping library, offering both Bourne shell and Bash style escaping
    of ByteStrings.

category:             Text
abi:                  6cfbe9813465d446146576f3af64eedc
exposed:              True
exposed-modules:      Data.ByteString.ShellEscape Text.ShellEscape
hidden-modules:
    Data.ByteString.ShellEscape.Escape
    Data.ByteString.ShellEscape.EscapeVector
    Data.ByteString.ShellEscape.Sh Data.ByteString.ShellEscape.Bash
    Data.ByteString.ShellEscape.Put

import-dirs:          /usr/lib/ghc-9.0.2/site-local/shell-escape-0.2.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/shell-escape-0.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-shell-escape
hs-libraries:         HSshell-escape-0.2.0-31vqIL3ffgTBybBmBztQi6
depends:
    base-4.15.1.0 binary-0.8.8.0 bytestring-0.10.12.1
    containers-0.6.4.1 vector-0.12.3.1-DWLcs41oUpGB6FR7Q3d3DL

haddock-interfaces:
    /usr/share/doc/haskell-shell-escape/html/shell-escape.haddock

haddock-html:         /usr/share/doc/haskell-shell-escape/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-shell-escape-0.2.0-158-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-shell-escape.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 shell-escape
version:              0.2.0
visibility:           public
id:                   shell-escape-0.2.0-DXSbafsAVNo6xl1hBldvFV
key:                  shell-escape-0.2.0-DXSbafsAVNo6xl1hBldvFV
license:              BSD-3-Clause
maintainer:           oss@solidsnack.be
author:               Jason Dusek
homepage:             http://github.com/solidsnack/shell-escape
synopsis:             Shell escaping library.
description:
    Shell escaping library, offering both Bourne shell and Bash style escaping
    of ByteStrings.

category:             Text
abi:                  c2dde547e4bf7da6a2b2f79df27f6d65
exposed:              True
exposed-modules:      Data.ByteString.ShellEscape Text.ShellEscape
hidden-modules:
    Data.ByteString.ShellEscape.Escape
    Data.ByteString.ShellEscape.EscapeVector
    Data.ByteString.ShellEscape.Sh Data.ByteString.ShellEscape.Bash
    Data.ByteString.ShellEscape.Put

import-dirs:          /usr/lib/ghc-9.0.2/site-local/shell-escape-0.2.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/shell-escape-0.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-shell-escape
hs-libraries:         HSshell-escape-0.2.0-DXSbafsAVNo6xl1hBldvFV
depends:
    base-4.15.1.0 binary-0.8.8.0 bytestring-0.10.12.1
    containers-0.6.4.1 vector-0.12.3.1-37YOJsTp4sSIT9CMAp9q9Q

haddock-interfaces:
    /usr/share/doc/haskell-shell-escape/html/shell-escape.haddock

haddock-html:         /usr/share/doc/haskell-shell-escape/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
